@@ -1609,6 +1609,14 @@ var toc = {
 }
 ,
 {
+"title": "blank_to_null",
+"url": "ref_builtins_string.html#ref_builtin_blank_to_null",
+"isFile": false,
+"children": [
+]
+}
+,
+{
 "title": "cap_first",
 "url": "ref_builtins_string.html#ref_builtin_cap_first",
 "isFile": false,
@@ -1681,6 +1689,14 @@ var toc = {
 }
 ,
 {
+"title": "empty_to_null",
+"url": "ref_builtins_string.html#ref_builtin_empty_to_null",
+"isFile": false,
+"children": [
+]
+}
+,
+{
 "title": "ends_with",
 "url": "ref_builtins_string.html#ref_builtin_ends_with",
 "isFile": false,
@@ -1929,6 +1945,14 @@ var toc = {
 }
 ,
 {
+"title": "trim_to_null",
+"url": "ref_builtins_string.html#ref_builtin_trim_to_null",
+"isFile": false,
+"children": [
+]
+}
+,
+{
 "title": "truncate, truncate_...",
 "url": "ref_builtins_string.html#ref_builtin_truncate",
 "isFile": false,
@@ -3249,7 +3273,7 @@ var toc = {
 }
 ,
 {
-"title": "switch, case, default, break",
+"title": "switch, on, case, default, break",
 "url": "ref_directive_switch.html",
 "isFile": true,
 "children": [
@@ -3686,13 +3710,36 @@ var toc = {
 "isFile": true,
 "children": [
 {
+"title": "2.3.34",
+"url": "versions_2_3_34.html",
+"isFile": true,
+"children": [
+{
+"title": "Changes on the FTL side",
+"url": "versions_2_3_34.html#autoid_150",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "Changes on the Java side",
+"url": "versions_2_3_34.html#autoid_151",
+"isFile": false,
+"children": [
+]
+}
+]
+}
+,
+{
 "title": "2.3.33",
 "url": "versions_2_3_33.html",
 "isFile": true,
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_33.html#autoid_150",
+"url": "versions_2_3_33.html#autoid_152",
 "isFile": false,
 "children": [
 ]
@@ -3715,7 +3762,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_32.html#autoid_151",
+"url": "versions_2_3_32.html#autoid_153",
 "isFile": false,
 "children": [
 ]
@@ -3723,7 +3770,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_32.html#autoid_152",
+"url": "versions_2_3_32.html#autoid_154",
 "isFile": false,
 "children": [
 ]
@@ -3738,7 +3785,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_31.html#autoid_153",
+"url": "versions_2_3_31.html#autoid_155",
 "isFile": false,
 "children": [
 ]
@@ -3746,7 +3793,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_31.html#autoid_154",
+"url": "versions_2_3_31.html#autoid_156",
 "isFile": false,
 "children": [
 ]
@@ -3761,7 +3808,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_30.html#autoid_155",
+"url": "versions_2_3_30.html#autoid_157",
 "isFile": false,
 "children": [
 ]
@@ -3769,7 +3816,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_30.html#autoid_156",
+"url": "versions_2_3_30.html#autoid_158",
 "isFile": false,
 "children": [
 ]
@@ -3784,7 +3831,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_29.html#autoid_157",
+"url": "versions_2_3_29.html#autoid_159",
 "isFile": false,
 "children": [
 ]
@@ -3792,7 +3839,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_29.html#autoid_158",
+"url": "versions_2_3_29.html#autoid_160",
 "isFile": false,
 "children": [
 ]
@@ -3807,7 +3854,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_28.html#autoid_159",
+"url": "versions_2_3_28.html#autoid_161",
 "isFile": false,
 "children": [
 ]
@@ -3815,7 +3862,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_28.html#autoid_160",
+"url": "versions_2_3_28.html#autoid_162",
 "isFile": false,
 "children": [
 ]
@@ -3823,7 +3870,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_28.html#autoid_161",
+"url": "versions_2_3_28.html#autoid_163",
 "isFile": false,
 "children": [
 ]
@@ -3838,7 +3885,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_27.html#autoid_162",
+"url": "versions_2_3_27.html#autoid_164",
 "isFile": false,
 "children": [
 ]
@@ -3846,7 +3893,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_27.html#autoid_163",
+"url": "versions_2_3_27.html#autoid_165",
 "isFile": false,
 "children": [
 ]
@@ -3861,7 +3908,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_26.html#autoid_164",
+"url": "versions_2_3_26.html#autoid_166",
 "isFile": false,
 "children": [
 ]
@@ -3869,7 +3916,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_26.html#autoid_165",
+"url": "versions_2_3_26.html#autoid_167",
 "isFile": false,
 "children": [
 ]
@@ -3877,7 +3924,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_26.html#autoid_166",
+"url": "versions_2_3_26.html#autoid_168",
 "isFile": false,
 "children": [
 ]
@@ -3892,7 +3939,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_25.html#autoid_167",
+"url": "versions_2_3_25.html#autoid_169",
 "isFile": false,
 "children": [
 ]
@@ -3900,7 +3947,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_25.html#autoid_168",
+"url": "versions_2_3_25.html#autoid_170",
 "isFile": false,
 "children": [
 ]
@@ -3915,22 +3962,6 @@ var toc = {
 "children": [
 {
 "title": "Legal changes",
-"url": "versions_2_3_24.html#autoid_169",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the FTL side",
-"url": "versions_2_3_24.html#autoid_170",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the Java side",
 "url": "versions_2_3_24.html#autoid_171",
 "isFile": false,
 "children": [
@@ -3938,12 +3969,28 @@ var toc = {
 }
 ,
 {
-"title": "Changes compared to 2.3.24 Release Candidate 1",
+"title": "Changes on the FTL side",
 "url": "versions_2_3_24.html#autoid_172",
 "isFile": false,
 "children": [
 ]
 }
+,
+{
+"title": "Changes on the Java side",
+"url": "versions_2_3_24.html#autoid_173",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "Changes compared to 2.3.24 Release Candidate 1",
+"url": "versions_2_3_24.html#autoid_174",
+"isFile": false,
+"children": [
+]
+}
 ]
 }
 ,
@@ -3954,22 +4001,6 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_23.html#autoid_173",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the Java side",
-"url": "versions_2_3_23.html#autoid_174",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Other changes",
 "url": "versions_2_3_23.html#autoid_175",
 "isFile": false,
 "children": [
@@ -3977,12 +4008,28 @@ var toc = {
 }
 ,
 {
-"title": "Notes",
+"title": "Changes on the Java side",
 "url": "versions_2_3_23.html#autoid_176",
 "isFile": false,
 "children": [
 ]
 }
+,
+{
+"title": "Other changes",
+"url": "versions_2_3_23.html#autoid_177",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "Notes",
+"url": "versions_2_3_23.html#autoid_178",
+"isFile": false,
+"children": [
+]
+}
 ]
 }
 ,
@@ -3993,7 +4040,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_22.html#autoid_177",
+"url": "versions_2_3_22.html#autoid_179",
 "isFile": false,
 "children": [
 ]
@@ -4001,7 +4048,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_22.html#autoid_178",
+"url": "versions_2_3_22.html#autoid_180",
 "isFile": false,
 "children": [
 ]
@@ -4009,7 +4056,7 @@ var toc = {
 ,
 {
 "title": "Notes",
-"url": "versions_2_3_22.html#autoid_179",
+"url": "versions_2_3_22.html#autoid_181",
 "isFile": false,
 "children": [
 ]
@@ -4024,7 +4071,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_21.html#autoid_180",
+"url": "versions_2_3_21.html#autoid_182",
 "isFile": false,
 "children": [
 ]
@@ -4032,7 +4079,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_21.html#autoid_181",
+"url": "versions_2_3_21.html#autoid_183",
 "isFile": false,
 "children": [
 ]
@@ -4040,7 +4087,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_21.html#autoid_182",
+"url": "versions_2_3_21.html#autoid_184",
 "isFile": false,
 "children": [
 ]
@@ -4055,7 +4102,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_20.html#autoid_183",
+"url": "versions_2_3_20.html#autoid_185",
 "isFile": false,
 "children": [
 ]
@@ -4063,7 +4110,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_20.html#autoid_184",
+"url": "versions_2_3_20.html#autoid_186",
 "isFile": false,
 "children": [
 ]
@@ -4071,7 +4118,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_20.html#autoid_185",
+"url": "versions_2_3_20.html#autoid_187",
 "isFile": false,
 "children": [
 ]
@@ -4086,7 +4133,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_19.html#autoid_186",
+"url": "versions_2_3_19.html#autoid_188",
 "isFile": false,
 "children": [
 ]
@@ -4094,7 +4141,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_19.html#autoid_187",
+"url": "versions_2_3_19.html#autoid_189",
 "isFile": false,
 "children": [
 ]
@@ -4109,7 +4156,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_18.html#autoid_188",
+"url": "versions_2_3_18.html#autoid_190",
 "isFile": false,
 "children": [
 ]
@@ -4117,7 +4164,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_18.html#autoid_189",
+"url": "versions_2_3_18.html#autoid_191",
 "isFile": false,
 "children": [
 ]
@@ -4132,7 +4179,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_17.html#autoid_190",
+"url": "versions_2_3_17.html#autoid_192",
 "isFile": false,
 "children": [
 ]
@@ -4140,7 +4187,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_17.html#autoid_191",
+"url": "versions_2_3_17.html#autoid_193",
 "isFile": false,
 "children": [
 ]
@@ -4148,7 +4195,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_17.html#autoid_192",
+"url": "versions_2_3_17.html#autoid_194",
 "isFile": false,
 "children": [
 ]
@@ -4163,7 +4210,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_16.html#autoid_193",
+"url": "versions_2_3_16.html#autoid_195",
 "isFile": false,
 "children": [
 ]
@@ -4171,7 +4218,7 @@ var toc = {
 ,
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_16.html#autoid_194",
+"url": "versions_2_3_16.html#autoid_196",
 "isFile": false,
 "children": [
 ]
@@ -4186,7 +4233,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_15.html#autoid_195",
+"url": "versions_2_3_15.html#autoid_197",
 "isFile": false,
 "children": [
 ]
@@ -4194,7 +4241,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_15.html#autoid_196",
+"url": "versions_2_3_15.html#autoid_198",
 "isFile": false,
 "children": [
 ]
@@ -4209,7 +4256,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_14.html#autoid_197",
+"url": "versions_2_3_14.html#autoid_199",
 "isFile": false,
 "children": [
 ]
@@ -4217,7 +4264,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_14.html#autoid_198",
+"url": "versions_2_3_14.html#autoid_200",
 "isFile": false,
 "children": [
 ]
@@ -4232,7 +4279,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_13.html#autoid_199",
+"url": "versions_2_3_13.html#autoid_201",
 "isFile": false,
 "children": [
 ]
@@ -4240,7 +4287,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_13.html#autoid_200",
+"url": "versions_2_3_13.html#autoid_202",
 "isFile": false,
 "children": [
 ]
@@ -4255,7 +4302,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_12.html#autoid_201",
+"url": "versions_2_3_12.html#autoid_203",
 "isFile": false,
 "children": [
 ]
@@ -4270,7 +4317,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_11.html#autoid_202",
+"url": "versions_2_3_11.html#autoid_204",
 "isFile": false,
 "children": [
 ]
@@ -4278,7 +4325,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_11.html#autoid_203",
+"url": "versions_2_3_11.html#autoid_205",
 "isFile": false,
 "children": [
 ]
@@ -4286,7 +4333,7 @@ var toc = {
 ,
 {
 "title": "Documentation changes",
-"url": "versions_2_3_11.html#autoid_204",
+"url": "versions_2_3_11.html#autoid_206",
 "isFile": false,
 "children": [
 ]
@@ -4301,7 +4348,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_10.html#autoid_205",
+"url": "versions_2_3_10.html#autoid_207",
 "isFile": false,
 "children": [
 ]
@@ -4309,7 +4356,7 @@ var toc = {
 ,
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_10.html#autoid_206",
+"url": "versions_2_3_10.html#autoid_208",
 "isFile": false,
 "children": [
 ]
@@ -4324,7 +4371,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_9.html#autoid_207",
+"url": "versions_2_3_9.html#autoid_209",
 "isFile": false,
 "children": [
 ]
@@ -4339,7 +4386,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_8.html#autoid_208",
+"url": "versions_2_3_8.html#autoid_210",
 "isFile": false,
 "children": [
 ]
@@ -4354,7 +4401,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_7.html#autoid_209",
+"url": "versions_2_3_7.html#autoid_211",
 "isFile": false,
 "children": [
 ]
@@ -4362,7 +4409,7 @@ var toc = {
 ,
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_7.html#autoid_210",
+"url": "versions_2_3_7.html#autoid_212",
 "isFile": false,
 "children": [
 ]
@@ -4377,7 +4424,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_7rc1.html#autoid_211",
+"url": "versions_2_3_7rc1.html#autoid_213",
 "isFile": false,
 "children": [
 ]
@@ -4385,7 +4432,7 @@ var toc = {
 ,
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_7rc1.html#autoid_212",
+"url": "versions_2_3_7rc1.html#autoid_214",
 "isFile": false,
 "children": [
 ]
@@ -4400,7 +4447,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_6.html#autoid_213",
+"url": "versions_2_3_6.html#autoid_215",
 "isFile": false,
 "children": [
 ]
@@ -4415,7 +4462,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_5.html#autoid_214",
+"url": "versions_2_3_5.html#autoid_216",
 "isFile": false,
 "children": [
 ]
@@ -4423,7 +4470,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_5.html#autoid_215",
+"url": "versions_2_3_5.html#autoid_217",
 "isFile": false,
 "children": [
 ]
@@ -4438,7 +4485,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_4.html#autoid_216",
+"url": "versions_2_3_4.html#autoid_218",
 "isFile": false,
 "children": [
 ]
@@ -4446,7 +4493,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_4.html#autoid_217",
+"url": "versions_2_3_4.html#autoid_219",
 "isFile": false,
 "children": [
 ]
@@ -4454,7 +4501,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_4.html#autoid_218",
+"url": "versions_2_3_4.html#autoid_220",
 "isFile": false,
 "children": [
 ]
@@ -4469,7 +4516,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_3_3.html#autoid_219",
+"url": "versions_2_3_3.html#autoid_221",
 "isFile": false,
 "children": [
 ]
@@ -4477,7 +4524,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_3.html#autoid_220",
+"url": "versions_2_3_3.html#autoid_222",
 "isFile": false,
 "children": [
 ]
@@ -4485,7 +4532,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_3_3.html#autoid_221",
+"url": "versions_2_3_3.html#autoid_223",
 "isFile": false,
 "children": [
 ]
@@ -4500,7 +4547,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_3_2.html#autoid_222",
+"url": "versions_2_3_2.html#autoid_224",
 "isFile": false,
 "children": [
 ]
@@ -4515,22 +4562,6 @@ var toc = {
 "children": [
 {
 "title": "Possible backward compatibility issue",
-"url": "versions_2_3_1.html#autoid_223",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the FTL side",
-"url": "versions_2_3_1.html#autoid_224",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the Java side",
 "url": "versions_2_3_1.html#autoid_225",
 "isFile": false,
 "children": [
@@ -4538,7 +4569,7 @@ var toc = {
 }
 ,
 {
-"title": "Other changes",
+"title": "Changes on the FTL side",
 "url": "versions_2_3_1.html#autoid_226",
 "isFile": false,
 "children": [
@@ -4546,13 +4577,29 @@ var toc = {
 }
 ,
 {
-"title": "The history of the releases before the final version",
+"title": "Changes on the Java side",
 "url": "versions_2_3_1.html#autoid_227",
 "isFile": false,
 "children": [
+]
+}
+,
+{
+"title": "Other changes",
+"url": "versions_2_3_1.html#autoid_228",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "The history of the releases before the final version",
+"url": "versions_2_3_1.html#autoid_229",
+"isFile": false,
+"children": [
 {
 "title": "Differences between the preview release and final\n release",
-"url": "versions_2_3_1.html#autoid_228",
+"url": "versions_2_3_1.html#autoid_230",
 "isFile": false,
 "children": [
 ]
@@ -4569,22 +4616,6 @@ var toc = {
 "children": [
 {
 "title": "Non backward-compatible changes!",
-"url": "versions_2_3.html#autoid_229",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the FTL side",
-"url": "versions_2_3.html#autoid_230",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the Java side",
 "url": "versions_2_3.html#autoid_231",
 "isFile": false,
 "children": [
@@ -4592,7 +4623,7 @@ var toc = {
 }
 ,
 {
-"title": "Other changes",
+"title": "Changes on the FTL side",
 "url": "versions_2_3.html#autoid_232",
 "isFile": false,
 "children": [
@@ -4600,12 +4631,15 @@ var toc = {
 }
 ,
 {
-"title": "The history of the releases before the final version",
+"title": "Changes on the Java side",
 "url": "versions_2_3.html#autoid_233",
 "isFile": false,
 "children": [
+]
+}
+,
 {
-"title": "Differences between the final release and Release Candidate\n 4",
+"title": "Other changes",
 "url": "versions_2_3.html#autoid_234",
 "isFile": false,
 "children": [
@@ -4613,15 +4647,12 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Release Candidate 4 and Release\n Candidate 3",
+"title": "The history of the releases before the final version",
 "url": "versions_2_3.html#autoid_235",
 "isFile": false,
 "children": [
-]
-}
-,
 {
-"title": "Differences between the Release Candidate 3 and Release\n Candidate 2",
+"title": "Differences between the final release and Release Candidate\n 4",
 "url": "versions_2_3.html#autoid_236",
 "isFile": false,
 "children": [
@@ -4629,7 +4660,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Release Candidate 2 and Release\n Candidate 1",
+"title": "Differences between the Release Candidate 4 and Release\n Candidate 3",
 "url": "versions_2_3.html#autoid_237",
 "isFile": false,
 "children": [
@@ -4637,7 +4668,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Release Candidate 1 and Preview 16\n releases",
+"title": "Differences between the Release Candidate 3 and Release\n Candidate 2",
 "url": "versions_2_3.html#autoid_238",
 "isFile": false,
 "children": [
@@ -4645,7 +4676,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 16 and Preview 15\n releases",
+"title": "Differences between the Release Candidate 2 and Release\n Candidate 1",
 "url": "versions_2_3.html#autoid_239",
 "isFile": false,
 "children": [
@@ -4653,7 +4684,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 15 and Preview 14\n releases",
+"title": "Differences between the Release Candidate 1 and Preview 16\n releases",
 "url": "versions_2_3.html#autoid_240",
 "isFile": false,
 "children": [
@@ -4661,7 +4692,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 14 and Preview 13\n releases",
+"title": "Differences between the Preview 16 and Preview 15\n releases",
 "url": "versions_2_3.html#autoid_241",
 "isFile": false,
 "children": [
@@ -4669,7 +4700,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 13 and Preview 12\n releases",
+"title": "Differences between the Preview 15 and Preview 14\n releases",
 "url": "versions_2_3.html#autoid_242",
 "isFile": false,
 "children": [
@@ -4677,7 +4708,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 12 and Preview 11\n releases",
+"title": "Differences between the Preview 14 and Preview 13\n releases",
 "url": "versions_2_3.html#autoid_243",
 "isFile": false,
 "children": [
@@ -4685,7 +4716,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 11 and Preview 10\n releases",
+"title": "Differences between the Preview 13 and Preview 12\n releases",
 "url": "versions_2_3.html#autoid_244",
 "isFile": false,
 "children": [
@@ -4693,7 +4724,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 10 and Preview 9\n releases",
+"title": "Differences between the Preview 12 and Preview 11\n releases",
 "url": "versions_2_3.html#autoid_245",
 "isFile": false,
 "children": [
@@ -4701,7 +4732,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 9 and Preview 8\n releases",
+"title": "Differences between the Preview 11 and Preview 10\n releases",
 "url": "versions_2_3.html#autoid_246",
 "isFile": false,
 "children": [
@@ -4709,7 +4740,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 8 and Preview 7\n releases",
+"title": "Differences between the Preview 10 and Preview 9\n releases",
 "url": "versions_2_3.html#autoid_247",
 "isFile": false,
 "children": [
@@ -4717,7 +4748,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 7 and Preview 6\n releases",
+"title": "Differences between the Preview 9 and Preview 8\n releases",
 "url": "versions_2_3.html#autoid_248",
 "isFile": false,
 "children": [
@@ -4725,7 +4756,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 6 and Preview 5\n releases",
+"title": "Differences between the Preview 8 and Preview 7\n releases",
 "url": "versions_2_3.html#autoid_249",
 "isFile": false,
 "children": [
@@ -4733,7 +4764,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 5 and Preview 4\n releases",
+"title": "Differences between the Preview 7 and Preview 6\n releases",
 "url": "versions_2_3.html#autoid_250",
 "isFile": false,
 "children": [
@@ -4741,7 +4772,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 4 and Preview 3\n releases",
+"title": "Differences between the Preview 6 and Preview 5\n releases",
 "url": "versions_2_3.html#autoid_251",
 "isFile": false,
 "children": [
@@ -4749,7 +4780,7 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 3 and Preview 2\n releases",
+"title": "Differences between the Preview 5 and Preview 4\n releases",
 "url": "versions_2_3.html#autoid_252",
 "isFile": false,
 "children": [
@@ -4757,12 +4788,28 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 2 and Preview 1\n releases",
+"title": "Differences between the Preview 4 and Preview 3\n releases",
 "url": "versions_2_3.html#autoid_253",
 "isFile": false,
 "children": [
 ]
 }
+,
+{
+"title": "Differences between the Preview 3 and Preview 2\n releases",
+"url": "versions_2_3.html#autoid_254",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "Differences between the Preview 2 and Preview 1\n releases",
+"url": "versions_2_3.html#autoid_255",
+"isFile": false,
+"children": [
+]
+}
 ]
 }
 ]
@@ -4775,7 +4822,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_2_8.html#autoid_254",
+"url": "versions_2_2_8.html#autoid_256",
 "isFile": false,
 "children": [
 ]
@@ -4783,7 +4830,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_8.html#autoid_255",
+"url": "versions_2_2_8.html#autoid_257",
 "isFile": false,
 "children": [
 ]
@@ -4791,7 +4838,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_2_8.html#autoid_256",
+"url": "versions_2_2_8.html#autoid_258",
 "isFile": false,
 "children": [
 ]
@@ -4806,7 +4853,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_7.html#autoid_257",
+"url": "versions_2_2_7.html#autoid_259",
 "isFile": false,
 "children": [
 ]
@@ -4821,7 +4868,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_2_6.html#autoid_258",
+"url": "versions_2_2_6.html#autoid_260",
 "isFile": false,
 "children": [
 ]
@@ -4829,7 +4876,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_6.html#autoid_259",
+"url": "versions_2_2_6.html#autoid_261",
 "isFile": false,
 "children": [
 ]
@@ -4837,7 +4884,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_2_6.html#autoid_260",
+"url": "versions_2_2_6.html#autoid_262",
 "isFile": false,
 "children": [
 ]
@@ -4852,7 +4899,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_5.html#autoid_261",
+"url": "versions_2_2_5.html#autoid_263",
 "isFile": false,
 "children": [
 ]
@@ -4867,7 +4914,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_4.html#autoid_262",
+"url": "versions_2_2_4.html#autoid_264",
 "isFile": false,
 "children": [
 ]
@@ -4875,7 +4922,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_2_4.html#autoid_263",
+"url": "versions_2_2_4.html#autoid_265",
 "isFile": false,
 "children": [
 ]
@@ -4890,7 +4937,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_2_3.html#autoid_264",
+"url": "versions_2_2_3.html#autoid_266",
 "isFile": false,
 "children": [
 ]
@@ -4898,7 +4945,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_3.html#autoid_265",
+"url": "versions_2_2_3.html#autoid_267",
 "isFile": false,
 "children": [
 ]
@@ -4913,7 +4960,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_2.html#autoid_266",
+"url": "versions_2_2_2.html#autoid_268",
 "isFile": false,
 "children": [
 ]
@@ -4928,7 +4975,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_2_1.html#autoid_267",
+"url": "versions_2_2_1.html#autoid_269",
 "isFile": false,
 "children": [
 ]
@@ -4936,7 +4983,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_2_1.html#autoid_268",
+"url": "versions_2_2_1.html#autoid_270",
 "isFile": false,
 "children": [
 ]
@@ -4951,22 +4998,6 @@ var toc = {
 "children": [
 {
 "title": "Non backward-compatible changes!",
-"url": "versions_2_2.html#autoid_269",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes in FTL (FreeMarker Template Language)",
-"url": "versions_2_2.html#autoid_270",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the Java side",
 "url": "versions_2_2.html#autoid_271",
 "isFile": false,
 "children": [
@@ -4974,7 +5005,7 @@ var toc = {
 }
 ,
 {
-"title": "Other changes",
+"title": "Changes in FTL (FreeMarker Template Language)",
 "url": "versions_2_2.html#autoid_272",
 "isFile": false,
 "children": [
@@ -4982,12 +5013,15 @@ var toc = {
 }
 ,
 {
-"title": "The history of the releases before the final version",
+"title": "Changes on the Java side",
 "url": "versions_2_2.html#autoid_273",
 "isFile": false,
 "children": [
+]
+}
+,
 {
-"title": "Differences between the final and RC2 releases",
+"title": "Other changes",
 "url": "versions_2_2.html#autoid_274",
 "isFile": false,
 "children": [
@@ -4995,15 +5029,12 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the RC2 and RC1 releases",
+"title": "The history of the releases before the final version",
 "url": "versions_2_2.html#autoid_275",
 "isFile": false,
 "children": [
-]
-}
-,
 {
-"title": "Differences between the Preview 2 and RC1 releases",
+"title": "Differences between the final and RC2 releases",
 "url": "versions_2_2.html#autoid_276",
 "isFile": false,
 "children": [
@@ -5011,12 +5042,28 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the Preview 1 and Preview 2\n releases",
+"title": "Differences between the RC2 and RC1 releases",
 "url": "versions_2_2.html#autoid_277",
 "isFile": false,
 "children": [
 ]
 }
+,
+{
+"title": "Differences between the Preview 2 and RC1 releases",
+"url": "versions_2_2.html#autoid_278",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "Differences between the Preview 1 and Preview 2\n releases",
+"url": "versions_2_2.html#autoid_279",
+"isFile": false,
+"children": [
+]
+}
 ]
 }
 ]
@@ -5029,7 +5076,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_1_5.html#autoid_278",
+"url": "versions_2_1_5.html#autoid_280",
 "isFile": false,
 "children": [
 ]
@@ -5044,7 +5091,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the Java side",
-"url": "versions_2_1_4.html#autoid_279",
+"url": "versions_2_1_4.html#autoid_281",
 "isFile": false,
 "children": [
 ]
@@ -5059,7 +5106,7 @@ var toc = {
 "children": [
 {
 "title": "Changes on the FTL side",
-"url": "versions_2_1_3.html#autoid_280",
+"url": "versions_2_1_3.html#autoid_282",
 "isFile": false,
 "children": [
 ]
@@ -5067,7 +5114,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_1_3.html#autoid_281",
+"url": "versions_2_1_3.html#autoid_283",
 "isFile": false,
 "children": [
 ]
@@ -5082,7 +5129,7 @@ var toc = {
 "children": [
 {
 "title": "Changes in FTL (FreeMarker Template Language)",
-"url": "versions_2_1_2.html#autoid_282",
+"url": "versions_2_1_2.html#autoid_284",
 "isFile": false,
 "children": [
 ]
@@ -5090,7 +5137,7 @@ var toc = {
 ,
 {
 "title": "Other changes",
-"url": "versions_2_1_2.html#autoid_283",
+"url": "versions_2_1_2.html#autoid_285",
 "isFile": false,
 "children": [
 ]
@@ -5105,7 +5152,7 @@ var toc = {
 "children": [
 {
 "title": "Changes in FTL (FreeMarker Template Language)",
-"url": "versions_2_1_1.html#autoid_284",
+"url": "versions_2_1_1.html#autoid_286",
 "isFile": false,
 "children": [
 ]
@@ -5113,7 +5160,7 @@ var toc = {
 ,
 {
 "title": "Changes on the Java side",
-"url": "versions_2_1_1.html#autoid_285",
+"url": "versions_2_1_1.html#autoid_287",
 "isFile": false,
 "children": [
 ]
@@ -5128,22 +5175,6 @@ var toc = {
 "children": [
 {
 "title": "Changes in FTL (FreeMarker Template Language)",
-"url": "versions_2_1.html#autoid_286",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes on the Java side",
-"url": "versions_2_1.html#autoid_287",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Other changes",
 "url": "versions_2_1.html#autoid_288",
 "isFile": false,
 "children": [
@@ -5151,12 +5182,28 @@ var toc = {
 }
 ,
 {
-"title": "Differences between the RC1 and final release",
+"title": "Changes on the Java side",
 "url": "versions_2_1.html#autoid_289",
 "isFile": false,
 "children": [
 ]
 }
+,
+{
+"title": "Other changes",
+"url": "versions_2_1.html#autoid_290",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "Differences between the RC1 and final release",
+"url": "versions_2_1.html#autoid_291",
+"isFile": false,
+"children": [
+]
+}
 ]
 }
 ,
@@ -5175,22 +5222,6 @@ var toc = {
 "children": [
 {
 "title": "Bugfixes",
-"url": "versions_2_0.html#autoid_290",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes to the Template language",
-"url": "versions_2_0.html#autoid_291",
-"isFile": false,
-"children": [
-]
-}
-,
-{
-"title": "Changes to the API",
 "url": "versions_2_0.html#autoid_292",
 "isFile": false,
 "children": [
@@ -5198,12 +5229,28 @@ var toc = {
 }
 ,
 {
-"title": "Miscellany",
+"title": "Changes to the Template language",
 "url": "versions_2_0.html#autoid_293",
 "isFile": false,
 "children": [
 ]
 }
+,
+{
+"title": "Changes to the API",
+"url": "versions_2_0.html#autoid_294",
+"isFile": false,
+"children": [
+]
+}
+,
+{
+"title": "Miscellany",
+"url": "versions_2_0.html#autoid_295",
+"isFile": false,
+"children": [
+]
+}
 ]
 }
 ,
@@ -5214,7 +5261,7 @@ var toc = {
 "children": [
 {
 "title": "Bug Fixes",
-"url": "versions_2_0RC3.html#autoid_294",
+"url": "versions_2_0RC3.html#autoid_296",
 "isFile": false,
 "children": [
 ]
@@ -5222,7 +5269,7 @@ var toc = {
 ,
 {
 "title": "Changes to the Template Language",
-"url": "versions_2_0RC3.html#autoid_295",
+"url": "versions_2_0RC3.html#autoid_297",
 "isFile": false,
 "children": [
 ]
@@ -5230,7 +5277,7 @@ var toc = {
 ,
 {
 "title": "API changes",
-"url": "versions_2_0RC3.html#autoid_296",
+"url": "versions_2_0RC3.html#autoid_298",
 "isFile": false,
 "children": [
 ]
@@ -5245,7 +5292,7 @@ var toc = {
 "children": [
 {
 "title": "Changes to Template Language",
-"url": "versions_2_0RC2.html#autoid_297",
+"url": "versions_2_0RC2.html#autoid_299",
 "isFile": false,
 "children": [
 ]
@@ -5253,7 +5300,7 @@ var toc = {
 ,
 {
 "title": "API Changes",
-"url": "versions_2_0RC2.html#autoid_298",
+"url": "versions_2_0RC2.html#autoid_300",
 "isFile": false,
 "children": [
 ]
@@ -5268,7 +5315,7 @@ var toc = {
 "children": [
 {
 "title": "Support for Numerical operations, both arithmetic and\n boolean, as well as numerical ranges.",
-"url": "versions_2_0RC1.html#autoid_299",
+"url": "versions_2_0RC1.html#autoid_301",
 "isFile": false,
 "children": [
 ]
@@ -5276,7 +5323,7 @@ var toc = {
 ,
 {
 "title": "API Changes",
-"url": "versions_2_0RC1.html#autoid_300",
+"url": "versions_2_0RC1.html#autoid_302",
 "isFile": false,
 "children": [
 ]
@@ -5284,7 +5331,7 @@ var toc = {
 ,
 {
 "title": "Syntactical Miscellany",
-"url": "versions_2_0RC1.html#autoid_301",
+"url": "versions_2_0RC1.html#autoid_303",
 "isFile": false,
 "children": [
 ]
